@@ -978,7 +978,7 @@ class LookupLib(object):
         return lookup
 
     def _load_clublogXML(self,
-                        url="https://secure.clublog.org/cty.php",
+                        url="https://cdn.clublog.org/cty.php",
                         apikey=None,
                         cty_file=None):
         """ Load and process the ClublogXML file either as a download or from file
@@ -1426,9 +1426,13 @@ class LookupLib(object):
         mapping = None
 
         with open(country_mapping_filename, "r") as f:
-            mapping = json.loads(f.read(),encoding='UTF-8')
+            mapping = json.loads(f.read())
 
-        cty_list = plistlib.readPlist(cty_file)
+        with open(cty_file, 'rb') as f:        
+            try:
+                cty_list = plistlib.load(f) #New API (Python >=3.4)
+            except AttributeError:
+                cty_list = plistlib.readPlist(cty_file) #Old API (Python >=2.7 && <=3.8) 
 
         for item in cty_list:
             entry = {}
@@ -1514,7 +1518,7 @@ class LookupLib(object):
         Deserialize a JSON into a dictionary
         """
 
-        my_dict = json.loads(json_data.decode('utf8'), encoding='UTF-8')
+        my_dict = json.loads(json_data.decode('utf8'))
 
         for item in my_dict:
             if item == const.ADIF:
