@@ -121,7 +121,7 @@ def get_clublog_users(**kwargs):
     files = zip_file.namelist()
     cl_json_unzipped = zip_file.read(files[0]).decode('utf8').replace("'", '"')
 
-    cl_data = json.loads(cl_json_unzipped, encoding='UTF-8')
+    cl_data = json.loads(cl_json_unzipped)
 
     error_count = 0
 
@@ -203,4 +203,4 @@ def get_eqsl_users(**kwargs):
     else:
         raise IOError("HTTP Error: " + str(result.status_code))
 
-    return eqsl
\ No newline at end of file
+    return eqsl
